@@ -1,21 +1,29 @@
 import React from 'react'
 import ModalPattern from './ModalPattern'
-import { bindMethods, propOrState, excludeKeys } from 'patternfly-react'
-
-// TODO(vs) remove once patternfly-react PR is merged:
-//  https://github.com/patternfly/patternfly-react/pull/343
+import { excludeKeys, filterKeys } from 'patternfly-react'
 
 class StatefulModalPattern extends React.Component {
   static getDerivedStateFromProps (nextProps, prevState) {
-    return {
-      show: propOrState(nextProps, prevState, 'show')
+    if (nextProps.show !== prevState.lastPropShow) {
+      return {
+        show: nextProps.show,
+        lastPropShow: nextProps.show
+      }
     }
+
+    return null
   }
 
   constructor (props) {
     super(props)
-    this.state = { show: false }
-    bindMethods(this, ['open', 'close'])
+    this.state = {
+      show: props.show,
+      lastPropShow: props.show
+    }
+
+    this.open = this.open.bind(this)
+    this.close = this.close.bind(this)
+    this.modalPropNames = Object.keys(StatefulModalPattern.propTypes)
   }
 
   open () {
@@ -26,14 +34,12 @@ class StatefulModalPattern extends React.Component {
     this.setState({ show: false })
   }
 
-  getModalPatternProps () {
-    return this.props
-  }
-
   render () {
+    const propsForModalPattern = filterKeys(this.props, key => this.modalPropNames.includes(key))
+
     return (
       <ModalPattern
-        {...this.getModalPatternProps()}
+        {...propsForModalPattern}
         show={this.state.show}
         onClose={this.close}
       />
@@ -46,7 +52,8 @@ StatefulModalPattern.propTypes = {
 }
 
 StatefulModalPattern.defaultProps = {
-  ...excludeKeys(ModalPattern.defaultProps, ['onClose', 'show'])
+  ...excludeKeys(ModalPattern.defaultProps, ['onClose', 'show']),
+  show: false
 }
 
 export default StatefulModalPattern
