@@ -122,6 +122,12 @@ const messageDescriptors = {
     description: 'text shown to compare currently used vs. total value'
   },
 
+  nonAvailableValue: {
+    id: 'common.nonAvailableValue',
+    defaultMessage: 'N/A',
+    description: 'text shown when a value is not available'
+  },
+
   // dashboard related strings
 
   dashboardTitle: {
@@ -739,6 +745,11 @@ const messageDescriptors = {
     defaultMessage: '{vmName} is based on a thin template, make sure the template\'s disks are present on the target storage domain',
     description: 'message shown when thin template disk are not present on target SD'
   },
+  exportVmErrorTitle: {
+    id: 'export.vm.exportFailedTitle',
+    defaultMessage: 'Export VM Failed',
+    description: 'title for the alert box shown when ovirt-engine returns an error'
+  },
   // manage VM's vGPU modal dialog related strings
 
   vmManageGpuDataError: {
@@ -755,7 +766,7 @@ const messageDescriptors = {
 
   vmManageGpuEmptyStateTitle: {
     id: 'vm.gpu.emptyState.title',
-    defaultMessage: 'No available hosts with vGPUs attached',
+    defaultMessage: 'No hosts with vGPUs attached',
     description: 'title of the empty state component'
   },
 
@@ -767,13 +778,25 @@ const messageDescriptors = {
 
   vmManageGpuBodyDescription: {
     id: 'vm.gpu.body.descrption',
-    defaultMessage: 'Select a vGPU on host(s) that you would like to use. The selected host(s) will automatically be pinned to the VM',
+    defaultMessage: 'Select vGPU(s) that you would like to use with this VM. ',
     description: 'Manage vGPU dialog body description'
   },
 
+  vmManageGpuBodySubTitleSelectionsCards: {
+    id: 'vm.gpu.body.selections.cards.label',
+    defaultMessage: 'Selected card name(s)',
+    description: 'Manage vGPU dialog body label `Card name(s)`'
+  },
+
+  vmManageGpuBodySubTitleSelectionsCardsEmpty: {
+    id: 'vm.gpu.body.subtitle.selections.cards.empty',
+    defaultMessage: 'No cards are currently selected',
+    description: 'Manage vGPU dialog body empty message `Card name(s)`'
+  },
+
   vmManageGpuSearchButtonPlaceholder: {
     id: 'vm.gpu.body.search.placeholder',
-    defaultMessage: 'Enter a search term',
+    defaultMessage: 'Search for a vGPU device or host',
     description: 'Manage vGPU dialog search field placeholder'
   },
 
@@ -813,6 +836,12 @@ const messageDescriptors = {
     description: 'label of `Product` in VM Manage vGPU dialog table'
   },
 
+  vmManageGpuTableAddress: {
+    id: 'vm.gpu.table.address',
+    defaultMessage: 'Address',
+    description: 'label of `Address` in VM Manage vGPU dialog table'
+  },
+
   vmManageGpuTableNumberOfHeads: {
     id: 'vm.gpu.table.numberOfHeads',
     defaultMessage: 'Number of heads',
